.. Merlin Systems documentation master file, created by
   sphinx-quickstart on Wed Mar  9 18:53:58 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Merlin Systems
==============

The Merlin Systems library provides facilities that simply building a recommender system for batch or serving.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   API Documentation <api/index>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
